{%- set git = git_workflow if git_workflow else {} -%}
{%- set branches = git.get('branches', {}) -%}
{%- set prefixes = git.get('commit_prefixes', []) -%}
## 4.3 Git Collaboration Standards

### Branch Strategy
```
{{ branches.get('main', 'main') }}                 # stable release
+-- {{ branches.get('dev', 'dev') }}              # development mainline
|   +-- {{ branches.get('feature_prefix', 'feature/') }}{feature-name}     # feature development
|   +-- {{ branches.get('design_prefix', 'design/') }}{design-doc}    # design iteration
|   +-- {{ branches.get('refactor_prefix', 'refactor/') }}{module-name}    # refactoring
|   +-- {{ branches.get('fix_prefix', 'fix/') }}{issue-desc}       # bug fix
```

### Commit Prefixes
```
{% for p in prefixes -%}
{{ p.get('prefix', '') }}  {{ p.get('description', '') }}
{% endfor -%}
```
{% if git.get('commit_required', True) %}
### Git Commit Requirements (important)

> **Every productive dialogue must produce a Git commit, recording the evolution of thinking**

Git history is not just code versioning -- it is a **record of design thinking evolution**.

---
{% endif -%}
