{%- set decisions = confirmed_decisions if confirmed_decisions is iterable and confirmed_decisions is not mapping else [] -%}
# Confirmed Decisions Summary

{% if decisions -%}
| ID | Decision | Choice | Rationale |
|----|----------|--------|-----------|
{% for d in decisions -%}
| {{ d.get('id', '') }} | {{ d.get('title', '') }} | {{ d.get('choice', '') }} | {{ d.get('reason', '') }} |
{% endfor -%}
{% else -%}
*No confirmed decisions yet. Will be recorded as the project progresses.*
{% endif %}
---
