{%- set docs = documentation if documentation else {} -%}
{%- set context_file = docs.get('context_file', 'docs/CONTEXT.md') -%}
# XIV. Quick Reference

## Starting a New Dialogue

```
Continue project development.
Please read CONTRIBUTING_AI.md and {{ context_file }} to restore context first.
Goal for this dialogue: {your goal}
```

## Before Ending a Dialogue

```
Please update {{ context_file }} to save current progress.
Summarize the decisions and outputs of this dialogue.
Then git commit to record this dialogue.
```

## Protocol Self-Check Trigger

```
check protocol
or
protocol check
or
vibecollab check
```

## Vibe Check

```
Before continuing, let's confirm:
- Are we aligned in understanding?
- Is this the right direction?
- Is there anything I haven't considered?
```

---
