{%- set sym = symbology if symbology else {} -%}
# XI. Symbology Annotation System

This protocol uses a unified symbol system to ensure communication consistency:

{% for category, symbols in sym.items() -%}
## {{ category.replace('_', ' ').title() }}

| Symbol | Meaning |
|--------|---------|
{% for s in symbols -%}
| `{{ s.get('symbol', '') }}` | {{ s.get('meaning', '') }} |
{% endfor %}
{% endfor -%}
---
