{%- set tu = task_unit if task_unit else {} -%}
{%- set statuses = tu.get('statuses', ['TODO', 'IN_PROGRESS', 'REVIEW', 'DONE']) -%}
# IV. Development Workflow Protocol

## 4.1 Task Unit Definition

Development is driven by **dialogue task units**, not dates:

```
Task Unit:
+-- ID: {{ tu.get('id_pattern', 'TASK-{role}-{seq}') }}
{% for field in tu.get('required_fields', []) if field != 'id' -%}
+-- {{ field }}
{% endfor -%}
+-- status: {{ statuses | join(' / ') }}
```
