{%- set cl = contributing_ai_changelog if contributing_ai_changelog is iterable and contributing_ai_changelog is not mapping else [] -%}
# CONTRIBUTING_AI.md Iteration Log

| Version | Date | Changes |
|---------|------|---------|
{% if cl -%}
{% for entry in cl -%}
| {{ entry.get('version', '') }} | {{ entry.get('date', '') }} | {{ entry.get('changes', '') }} |
{% endfor -%}
{% else -%}
| v1.0 | {{ now.strftime('%Y-%m-%d') }} | Initial version |
{% endif %}
---
